import io.qameta.allure.AllureId;
import io.qameta.allure.Description;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.apache.logging.log4j.ThreadContext;
import org.junit.jupiter.api.*;
import org.openqa.selenium.*;
import org.openqa.selenium.chrome.ChromeDriver;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;

import java.time.Duration;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

public class testError {
    static Logger logger = LogManager.getLogger(testError.class);
    public static boolean testFailed;
    private static String testName = null;
    static WebDriver driver;
    static WebDriverWait wait;

    @BeforeEach
    public void setUp(TestInfo testInfo) {
        driver = new ChromeDriver();

        wait = new WebDriverWait(driver, Duration.ofSeconds(10));

        testName = testInfo.getDisplayName().replaceAll("[^a-zA-Z0-9_\\-]", "_");
        ThreadContext.put("testName", "TestNameValue");
        ThreadContext.put("testName", testName);
        logger.info("Запуск теста: " + testName);


        driver.get("https://g.co/kgs/NKFefHW");
        logger.info("Перешли на страницу игры \"Крестики-нолики\".");
    }

    @AfterEach
    public void tearDown(TestInfo testInfo) {

        String testName = testInfo.getDisplayName().replaceAll(" ", "_");
        ThreadContext.put("testName", testName);
        logger.info("Завершение теста: " + testName);

        if (driver != null) {

            try {
                if (testFailed) {
                    String screenshotFileName = String.format("screenshot_%s_%s.png",
                            testName,
                            LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyy-MM-dd_HH-mm-ss")));
                    screenshotLogic.takeScreenshot(testName, screenshotFileName);
                    logger.info("Скриншот сохранен: " + screenshotFileName);
                }

            } catch (WebDriverException e) {
                logger.error("Ошибка при захвате скриншота: " + e.getMessage());
            } finally {
                driver.quit();
                logger.info("Закрыли браузер.");
            }
        }

        ThreadContext.clearAll();
    }


    @DisplayName("TestError")
    @Description("Падение теста, создание искусственной ошибки.")
    @AllureId("002")
    @Test
    public void testTimeoutWaitingForElement() {
        try {
            WebElement nonExistentElement = wait.until(ExpectedConditions.elementToBeClickable(By.id("nonExistentId")));
            nonExistentElement.click();
        } catch (TimeoutException e) {
            testFailed = true;
            logger.error("Таймаут ожидания элемента: " + e.getMessage());
            throw new RuntimeException("Тест успешно завершился с ошибкой: таймаут ожидания.");
        }
    }
}
