import io.qameta.allure.AllureId;
import io.qameta.allure.Description;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.apache.logging.log4j.ThreadContext;
import org.junit.jupiter.api.*;
import org.openqa.selenium.*;
import org.openqa.selenium.chrome.ChromeDriver;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;

import java.time.Duration;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;


public class testRandomMoves {
    int numberOfTests = 5;
    int xWins = 0, oWins = 0, draws = 0;
    static Logger logger = LogManager.getLogger(testRandomMoves.class);
    public static boolean testFailed;
    static WebDriver driver;
    static WebDriverWait wait;

    private static String testName = null;




        @BeforeEach
        public void setUp(TestInfo testInfo) {
            driver = new ChromeDriver();

            wait = new WebDriverWait(driver, Duration.ofSeconds(10));


            testName = testInfo.getDisplayName().replaceAll("[^a-zA-Z0-9_\\-]", "_");
            ThreadContext.put("testName", "TestNameValue");
            ThreadContext.put("testName", testName);
            logger.info("Запуск теста: " + testName);


            driver.get("https://g.co/kgs/NKFefHW");
            logger.info("Перешли на страницу игры \"Крестики-нолики\".");
        }

        @AfterEach
        public void tearDown(TestInfo testInfo) {

            String testName = testInfo.getDisplayName().replaceAll(" ", "_");
            ThreadContext.put("testName", testName);
            logger.info("Завершение теста: " + testName);

            if (driver != null) {

                try {
                    if (testFailed) {
                        String screenshotFileName = String.format("screenshot_%s_%s.png",
                                testName,
                                LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyy-MM-dd_HH-mm-ss")));
                        screenshotLogic.takeScreenshot(testName, screenshotFileName);
                        logger.info("Скриншот сохранен: " + screenshotFileName);
                    }

                } catch (WebDriverException e) {
                    logger.error("Ошибка при захвате скриншота: " + e.getMessage());
                } finally {
                    driver.quit();
                    logger.info("Закрыли браузер.");
                }
            }

            ThreadContext.clearAll();
        }



    //Основной тест

    @DisplayName("MainTest")
    @Description("Валидный тест игры. Победа/Проигрыш/Ничья - генерируется на рандом")
    @AllureId("001")
    @Test
    public void randomMovesTest() throws InterruptedException {
        for (int i = 0; i < numberOfTests; i++) {
            logger.info("Запуск игры № " + (i + 1));


            if (!selectGameModeLogic.selectGameMode(wait, driver)) {
                logger.error("Пропускаем игру № " + (i + 1) + " из-за ошибки при выборе режима.");
                continue;
            }


            simulatePauseLogic.simulatePause(489,508);


            String firstPlayer = (i % 2 == 0) ? "X" : "O";
            logger.info("Первый ход делает игрок: " + firstPlayer);
            String result = playGameLogic.playGame(i + 1, firstPlayer, wait, driver);


            if (result.equals("X")) {
                xWins++;
            } else if (result.equals("O")) {
                oWins++;
            } else {
                draws++;
            }

            restartGameLogic.restartGame(wait, driver);
        }


        logger.info(String.format("result all games: \nX win: %d, \nO win: %d, \nDraw: %d%n", xWins, oWins, draws));
    }








}
